/**
 * Copyright (c) 2008, Jose Enrique Bolanos, Jorge Villalobos
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Jose Enrique Bolanos, Jorge Villalobos nor the names
 *    of its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **/

Components.utils.import("resource://firefm/fmCommon.js");

/**
 * FireFM chrome namespace. We need a separate one because this one is defined
 * per window.
 */
if (typeof(FireFMChrome) == 'undefined') {
  var FireFMChrome = {};
};

/**
 * Preferences window controller. Manages UI events that occur in the
 * preferences window.
 */
FireFMChrome.PreferencesWindow = {
  /* Logger for this object. */
  _logger : null,

  /**
   * Initializes the object.
   */
  init : function() {
    let os;
    let bundle;

    this._logger = Log4Moz.Service.getLogger("FireFMChrome.PreferencesWindow");
    this._logger.level = Log4Moz.Level["All"];
    this._logger.debug("init");

    bundle = document.getElementById("firefm-string-bundle");
    os = FireFM.getOperatingSystem();

    if ((FireFM.OS_WINDOWS == os) || (FireFM.OS_WINDOWS_VISTA == os)) {
      document.title = bundle.getString("firefm.options.title");
    } else {
      document.title = bundle.getString("firefm.optionsUnix.title");
    }
  },

  /**
   * Unloads the object.
   */
  uninit : function() {
    this._logger.debug("uninit");
  },

  /**
   * Opens the Learn More page on a browser window. This page informs the user
   * about what is Scrobble.
   * @param aEvent the event that triggered this action.
   */
  openLearnMorePage : function(aEvent) {
    this._logger.debug("openLearnMorePage");
    openURL(FireFM.Remote.URL_HELP);
  },

  /**
   * Clears the recent station history.
   * @param aEvent the event that triggered this action.
   */
  clearRecentHistory : function(aEvent) {
    this._logger.debug("clearRecentHistory");
    // disable the button, since it will no longer do anything.
    aEvent.target.setAttribute("disabled", true);
    FireFM.History.clearRecentHistory();
  }
};

window.addEventListener(
  "load", function() { FireFMChrome.PreferencesWindow.init(); }, false);
window.addEventListener(
  "unload", function() { FireFMChrome.PreferencesWindow.uninit(); }, false);
